
# DBHELPY

dbhelpy is an easy to use Python library that allows you to interact with your sqlite database using dbhelpy methods

For more information check out the documentation [here](https://dbhelpy.readthedocs.io/en/main/index.html).
# Install
```python
pip install dbhelpy
```

# How to Start
```python
from dbhelpy.dbhelpy import Helpy

db = Helpy('database.db')
```


